@@ -1,2 +1,2 @@
 from .shared.exports import *  # noqa - these will probably be wrapped later in client
-from .client import track_command, track_event, dispatch_events
+from .client import track_command
